@@ -8,6 +8,7 @@ import tasknode.tasks as tasks
 
 app = typer.Typer(no_args_is_help=True)
 
+
 def cleanup_deploy_files():
     """Clean up temporary deployment files."""
     try:
@@ -18,9 +19,11 @@ def cleanup_deploy_files():
     except Exception as e:
         typer.echo(f"Warning: Error during cleanup: {str(e)}", err=True)
 
+
 # Register the cleanup function to run on exit
 atexit.register(cleanup_deploy_files)
 
+
 def show_available_commands(ctx: typer.Context, value: bool = True):
     if value:
         # fmt: off
@@ -38,7 +41,7 @@ def show_available_commands(ctx: typer.Context, value: bool = True):
         typer.echo("  • submit                    Submit a Python script to run")
         typer.echo("  • jobs                      List your TaskNode jobs")
         typer.echo("  • sample-notebook           Generate a sample Jupyter notebook to test with")
-        typer.echo("  • job <job_id || index>     Get details for a specific TaskNode job")
+        typer.echo("  • job <job_id || index>     Get status and details for a specific TaskNode job")
         typer.echo("\nℹ️  Help:")
         typer.echo("  • help                      Show help for the TaskNode CLI")
 
